@@ -1,10 +1,15 @@
 use crate::{parse_digest, Manifest};
 use hyper::body::HttpBody;
 use regex::Regex;
-use saphir::{hyper::body::Buf, prelude::*};
+use saphir::hyper::body::Buf;
+use saphir::prelude::*;
 use serde::Deserialize;
 use slog_scope::{debug, error};
-use std::{collections::HashMap, fs::create_dir_all, io, io::Write, path::Path};
+use std::collections::HashMap;
+use std::fs::create_dir_all;
+use std::io;
+use std::io::Write;
+use std::path::Path;
 use tokio_02::io::AsyncWriteExt;
 
 const REPOSITORY: &str = "repository";
@@ -112,7 +117,7 @@ impl SogarController {
         if let (Some(repository), Some(image_name), Some(digest)) =
             (map.get(REPOSITORY), map.get(IMAGE_NAME), map.get(DIGEST))
         {
-            if let Some(digest) = parse_digest(digest.to_string()) {
+            if let Some(digest) = parse_digest(digest) {
                 let path = Path::new(repository)
                     .join(image_name)
                     .join(ARTIFACTS_DIR)
@@ -163,7 +168,7 @@ impl SogarController {
         if let (Some(repository), Some(image_name), Some(digest)) = (map.get(REPOSITORY), map.get(IMAGE_NAME), digest) {
             let path = Path::new(repository).join(image_name).join(ARTIFACTS_DIR);
             if path.exists() {
-                if let Some(blob_digest) = parse_digest(digest.clone()) {
+                if let Some(blob_digest) = parse_digest(&digest) {
                     let path = path.join(blob_digest.digest_type.as_str());
                     if !path.exists() {
                         if let Err(e) = create_dir_all(path.as_path()) {
@@ -247,7 +252,7 @@ impl SogarController {
                         .and_then(|header| header.to_str().map_or(None, |result| Some(result.to_string())));
                 }
 
-                add_artifacts_info(tag.clone(), manifest_mime_type, image_path.as_path());
+                add_artifacts_info(tag, manifest_mime_type, image_path.as_path());
 
                 let mut response = SogarCustomResponse::new(StatusCode::CREATED);
                 response.header(
@@ -273,7 +278,7 @@ impl SogarController {
         {
             let image_path = Path::new(repository).join(image_name);
             let path = image_path.join(ARTIFACTS_DIR).join(tag);
-            let content_type = read_artifact_info(tag.to_string(), image_path.as_path());
+            let content_type = read_artifact_info(tag, image_path.as_path());
 
             if headers.contains_key(ACCEPT_HEADER) {
                 if let (Some(accept_value), Some(content_type)) = (
@@ -301,7 +306,7 @@ impl SogarController {
         if let (Some(repository), Some(image_name), Some(digest)) =
             (map.get(REPOSITORY), map.get(IMAGE_NAME), map.get(DIGEST))
         {
-            if let Some(digest) = parse_digest(digest.to_string()) {
+            if let Some(digest) = parse_digest(digest) {
                 let image_path = Path::new(repository).join(image_name);
                 let path = image_path
                     .join(ARTIFACTS_DIR)
@@ -310,7 +315,7 @@ impl SogarController {
                 let (status_code, file_result) = get_file_if_exists(path.as_path()).await;
 
                 if let Some(file) = file_result {
-                    let content_type = read_artifact_info(digest.value, image_path.as_path());
+                    let content_type = read_artifact_info(&digest.value, image_path.as_path());
 
                     let mut response = SogarCustomResponse::new(status_code);
                     response.file(file);
@@ -390,9 +395,8 @@ async fn get_file_if_exists(path: &Path) -> (StatusCode, Option<File>) {
     (StatusCode::NOT_FOUND, None)
 }
 
-pub fn add_artifacts_info(filename: String, manifest_mime: Option<String>, image_path: &Path) {
-    use std::fs::File;
-    use std::fs::OpenOptions;
+pub fn add_artifacts_info(filename: &str, manifest_mime: Option<String>, image_path: &Path) {
+    use std::fs::{File, OpenOptions};
 
     let content_path = image_path.join(ARTIFACTS_CONTENT);
     let filepath = image_path.join(ARTIFACTS_DIR).join(&filename);
@@ -412,7 +416,7 @@ pub fn add_artifacts_info(filename: String, manifest_mime: Option<String>, image
 
         if let Ok(mut file) = artifacts_content_file {
             for layer in manifest.layers {
-                if let Some(digest) = parse_digest(layer.digest.clone()) {
+                if let Some(digest) = parse_digest(&layer.digest) {
                     if let Err(e) = writeln!(file, "{}", format!("  {}: {}", digest.value, layer.media_type)) {
                         error!("Couldn't write to file: {}", e);
                     }
@@ -428,13 +432,12 @@ pub fn add_artifacts_info(filename: String, manifest_mime: Option<String>, image
     }
 }
 
-fn read_artifact_info(digest_value: String, image_path: &Path) -> Option<String> {
+fn read_artifact_info(digest_value: &str, image_path: &Path) -> Option<String> {
     use std::fs::File;
 
     let content_path = image_path.join(ARTIFACTS_CONTENT);
     match File::open(&content_path) {
         Ok(file) => {
-
             #[derive(Deserialize)]
             struct ArtifactsData {
                 artifacts: HashMap<String, String>,
@@ -447,10 +450,10 @@ fn read_artifact_info(digest_value: String, image_path: &Path) -> Option<String>
             }
 
             let blobs_data: ArtifactsData = yaml.unwrap();
-            if blobs_data.artifacts.contains_key(digest_value.as_str()) {
+            if blobs_data.artifacts.contains_key(digest_value) {
                 return blobs_data
                     .artifacts
-                    .get(digest_value.as_str())
+                    .get(digest_value)
                     .map(|mime_type| mime_type.to_string());
             }
         }
